@@ -3,9 +3,7 @@ from prefect._internal.compatibility.deprecated import (
 )
 
 from . import _version
-from .aiplatform import VertexAICustomTrainingJob  # noqa
 from .bigquery import BigQueryWarehouse  # noqa
-from .cloud_run import CloudRunJob  # noqa
 from .cloud_storage import GcsBucket  # noqa
 from .credentials import GcpCredentials  # noqa
 from .secret_manager import GcpSecret  # noqa
