@@ -1,4 +1,4 @@
-""" <!-- # noqa -->
+"""<!-- # noqa -->
 
 Module containing the Cloud Run worker used for executing flow runs as Cloud Run jobs.
 
@@ -16,7 +16,7 @@ prefect worker start --pool 'my-cloud-run-pool'
 
 ## Configuration
 Read more about configuring work pools
-[here](https://docs.prefect.io/latest/concepts/work-pools/#work-pool-overview).
+[here](https://docs.prefect.io/3.0/deploy/infrastructure-concepts/work-pools).
 
 ## Advanced Configuration
 !!! example "Using a custom Cloud Run job template"
@@ -117,9 +117,13 @@ Read more about configuring work pools
     on a per-deployment basis.
 
     ```yaml
-    # deployment.yaml
+    # prefect.yaml
+    deployments:
     ...
-    infra_overrides: {"my_custom_annotation": "my-custom-value"}
+      - name: my-deployment
+      ...
+      work_pool: my-cloud-run-pool
+        job_variables: {"my_custom_annotation": "my-custom-value"}
     ```
 
     Additionally, fields can be set to prevent configuration at the deployment
@@ -162,9 +166,8 @@ from anyio.abc import TaskStatus  # noqa
 from google.api_core.client_options import ClientOptions
 from googleapiclient import discovery
 from googleapiclient.discovery import Resource
-from pydantic import VERSION as PYDANTIC_VERSION
+from pydantic import Field, field_validator
 
-from prefect.exceptions import InfrastructureNotFound
 from prefect.logging.loggers import PrefectLogAdapter
 from prefect.utilities.asyncutils import run_sync_in_worker_thread
 from prefect.utilities.dockerutils import get_prefect_image_name
@@ -175,15 +178,8 @@ from prefect.workers.base import (
     BaseWorker,
     BaseWorkerResult,
 )
-
-if PYDANTIC_VERSION.startswith("2."):
-    from pydantic.v1 import Field, validator
-else:
-    from pydantic import Field, validator
-
-from prefect_gcp.cloud_run import Execution, Job
 from prefect_gcp.credentials import GcpCredentials
-from prefect_gcp.utilities import slugify_name
+from prefect_gcp.utilities import Execution, Job, slugify_name
 
 if TYPE_CHECKING:
     from prefect.client.schemas import FlowRun
@@ -290,7 +286,9 @@ class CloudRunWorkerJobConfiguration(BaseJobConfiguration):
         "If not provided credentials will be inferred from "
         "the local environment.",
     )
-    job_body: Dict[str, Any] = Field(template=_get_default_job_body_template())
+    job_body: Dict[str, Any] = Field(
+        json_schema_extra=dict(template=_get_default_job_body_template())
+    )
     timeout: Optional[int] = Field(
         default=600,
         gt=0,
@@ -411,7 +409,8 @@ class CloudRunWorkerJobConfiguration(BaseJobConfiguration):
         except KeyError:
             raise ValueError("Unable to verify args due to invalid job body template.")
 
-    @validator("job_body")
+    @field_validator("job_body")
+    @classmethod
     def _ensure_job_includes_all_required_components(cls, value: Dict[str, Any]):
         """
         Ensures that the job body includes all required components.
@@ -425,7 +424,8 @@ class CloudRunWorkerJobConfiguration(BaseJobConfiguration):
             )
         return value
 
-    @validator("job_body")
+    @field_validator("job_body")
+    @classmethod
     def _ensure_job_has_compatible_values(cls, value: Dict[str, Any]):
         """Ensure that the job body has compatible values."""
         patch = JsonPatch.from_diff(value, _get_base_job_body())
@@ -455,7 +455,7 @@ class CloudRunWorkerVariables(BaseVariables):
     region: str = Field(
         default="us-central1",
         description="The region where the Cloud Run Job resides.",
-        example="us-central1",
+        examples=["us-central1"],
     )
     credentials: Optional[GcpCredentials] = Field(
         title="GCP Credentials",
@@ -472,7 +472,7 @@ class CloudRunWorkerVariables(BaseVariables):
             "If not set, the latest Prefect image will be used. "
             "See https://cloud.google.com/run/docs/deploying#images."
         ),
-        example="docker.io/prefecthq/prefect:2-latest",
+        examples=["docker.io/prefecthq/prefect:3-latest"],
     )
     cpu: Optional[str] = Field(
         default=None,
@@ -482,8 +482,8 @@ class CloudRunWorkerVariables(BaseVariables):
             "(1000m = 1 CPU). See "
             "https://cloud.google.com/run/docs/configuring/cpu#setting-jobs."
         ),
-        example="1000m",
-        regex=r"^(\d*000)m$",
+        examples=["1000m"],
+        pattern=r"^(\d*000)m$",
     )
     memory: Optional[str] = Field(
         default=None,
@@ -493,8 +493,8 @@ class CloudRunWorkerVariables(BaseVariables):
             "Must be specified in units of 'G', 'Gi', 'M', or 'Mi'. "
             "See https://cloud.google.com/run/docs/configuring/memory-limits#setting."
         ),
-        example="512Mi",
-        regex=r"^\d+(?:G|Gi|M|Mi)$",
+        examples=["512Mi"],
+        pattern=r"^\d+(?:G|Gi|M|Mi)$",
     )
     vpc_connector_name: Optional[str] = Field(
         default=None,
@@ -507,7 +507,7 @@ class CloudRunWorkerVariables(BaseVariables):
         description="The name of the service account to use for the task execution "
         "of Cloud Run Job. By default Cloud Run jobs run as the default "
         "Compute Engine Service Account. ",
-        example="service-account@example.iam.gserviceaccount.com",
+        examples=["service-account@example.iam.gserviceaccount.com"],
     )
     keep_job: Optional[bool] = Field(
         default=False,
@@ -515,10 +515,10 @@ class CloudRunWorkerVariables(BaseVariables):
         description="Keep the completed Cloud Run Job after it has run.",
     )
     timeout: Optional[int] = Field(
+        title="Job Timeout",
         default=600,
         gt=0,
         le=3600,
-        title="Job Timeout",
         description=(
             "Max allowed duration the Job may be active before Cloud Run will "
             "actively try to mark it failed and kill associated containers (maximum of 3600 seconds, 1 hour)."
@@ -810,39 +810,3 @@ class CloudRunWorker(BaseWorker):
             )
 
             time.sleep(poll_interval)
-
-    async def kill_infrastructure(
-        self,
-        infrastructure_pid: str,
-        configuration: CloudRunWorkerJobConfiguration,
-        grace_seconds: int = 30,
-    ):
-        """
-        Stops a job for a cancelled flow run based on the provided infrastructure PID
-        and run configuration.
-        """
-        if grace_seconds != 30:
-            self._logger.warning(
-                f"Kill grace period of {grace_seconds}s requested, but GCP does not "
-                "support dynamic grace period configuration. See here for more info: "
-                "https://cloud.google.com/run/docs/reference/rest/v1/namespaces.jobs/delete"  # noqa
-            )
-
-        with self._get_client(configuration) as client:
-            await run_sync_in_worker_thread(
-                self._stop_job,
-                client=client,
-                namespace=configuration.project,
-                job_name=infrastructure_pid,
-            )
-
-    def _stop_job(self, client: Resource, namespace: str, job_name: str):
-        try:
-            Job.delete(client=client, namespace=namespace, job_name=job_name)
-        except Exception as exc:
-            if "does not exist" in str(exc):
-                raise InfrastructureNotFound(
-                    f"Cannot stop Cloud Run Job; the job name {job_name!r} "
-                    "could not be found."
-                ) from exc
-            raise
