@@ -11,9 +11,8 @@ from googleapiclient import discovery
 # noinspection PyProtectedMember
 from googleapiclient.discovery import Resource
 from googleapiclient.errors import HttpError
-from pydantic import VERSION as PYDANTIC_VERSION
+from pydantic import Field, PrivateAttr, field_validator
 
-from prefect.exceptions import InfrastructureNotFound
 from prefect.logging.loggers import PrefectLogAdapter
 from prefect.utilities.asyncutils import run_sync_in_worker_thread
 from prefect.utilities.dockerutils import get_prefect_image_name
@@ -24,14 +23,8 @@ from prefect.workers.base import (
     BaseWorker,
     BaseWorkerResult,
 )
-
-if PYDANTIC_VERSION.startswith("2."):
-    from pydantic.v1 import Field, PrivateAttr, validator
-else:
-    from pydantic import Field, PrivateAttr, validator
-
 from prefect_gcp.credentials import GcpCredentials
-from prefect_gcp.models.cloud_run_v2 import ExecutionV2, JobV2
+from prefect_gcp.models.cloud_run_v2 import ExecutionV2, JobV2, SecretKeySelector
 from prefect_gcp.utilities import slugify_name
 
 if TYPE_CHECKING:
@@ -108,8 +101,13 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
             "the local environment."
         ),
     )
+    env_from_secrets: Dict[str, SecretKeySelector] = Field(
+        default_factory=dict,
+        title="Environment Variables from Secrets",
+        description="Environment variables to set from GCP secrets when starting a flow run.",
+    )
     job_body: Dict[str, Any] = Field(
-        template=_get_default_job_body_template(),
+        json_schema_extra=dict(template=_get_default_job_body_template()),
     )
     keep_job: bool = Field(
         default=False,
@@ -125,7 +123,7 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         gt=0,
         le=86400,
         description=(
-            "Max allowed duration the job may be active before Cloud Run will "
+            "Max allowed duration the Job may be active before Cloud Run will "
             "actively try to mark it failed and kill associated containers (maximum of 86400 seconds, 1 day)."
         ),
     )
@@ -198,6 +196,14 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         Populates the job body with environment variables.
         """
         envs = [{"name": k, "value": v} for k, v in self.env.items()]
+        envs_from_secrets = [
+            {
+                "name": k,
+                "valueSource": {"secretKeyRef": v.model_dump()},
+            }
+            for k, v in self.env_from_secrets.items()
+        ]
+        envs.extend(envs_from_secrets)
 
         self.job_body["template"]["template"]["containers"][0]["env"] = envs
 
@@ -256,7 +262,8 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
             self.job_body["template"]["template"].pop("vpcAccess")
 
     # noinspection PyMethodParameters
-    @validator("job_body")
+    @field_validator("job_body")
+    @classmethod
     def _ensure_job_includes_all_required_components(cls, value: Dict[str, Any]):
         """
         Ensures that the job body includes all required components.
@@ -278,7 +285,8 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
         return value
 
     # noinspection PyMethodParameters
-    @validator("job_body")
+    @field_validator("job_body")
+    @classmethod
     def _ensure_job_has_compatible_values(cls, value: Dict[str, Any]):
         """Ensure that the job body has compatible values."""
         patch = JsonPatch.from_diff(value, _get_base_job_body())
@@ -299,7 +307,7 @@ class CloudRunWorkerJobV2Configuration(BaseJobConfiguration):
 
 class CloudRunWorkerV2Variables(BaseVariables):
     """
-    Default variables for the Cloud Run worker V2.
+    Default variables for the v2 Cloud Run worker.
 
     The schema for this class is used to populate the `variables` section of the
     default base job template.
@@ -319,7 +327,7 @@ class CloudRunWorkerV2Variables(BaseVariables):
         description="The region in which to run the Cloud Run job",
     )
     image: Optional[str] = Field(
-        default="prefecthq/prefect:2-latest",
+        default="prefecthq/prefect:3-latest",
         title="Image Name",
         description=(
             "The image to use for the Cloud Run job. "
@@ -332,6 +340,17 @@ class CloudRunWorkerV2Variables(BaseVariables):
             "The arguments to pass to the Cloud Run Job V2's entrypoint command."
         ),
     )
+    env_from_secrets: Dict[str, SecretKeySelector] = Field(
+        default_factory=dict,
+        title="Environment Variables from Secrets",
+        description="Environment variables to set from GCP secrets when starting a flow run.",
+        example={
+            "ENV_VAR_NAME": {
+                "secret": "SECRET_NAME",
+                "version": "latest",
+            }
+        },
+    )
     keep_job: bool = Field(
         default=False,
         title="Keep Job After Completion",
@@ -371,7 +390,7 @@ class CloudRunWorkerV2Variables(BaseVariables):
             "The memory to allocate to the Cloud Run job along with the units, which"
             "could be: G, Gi, M, Mi."
         ),
-        example="512Mi",
+        examples=["512Mi"],
         pattern=r"^\d+(?:G|Gi|M|Mi)$",
     )
     timeout: int = Field(
@@ -380,8 +399,8 @@ class CloudRunWorkerV2Variables(BaseVariables):
         le=86400,
         title="Job Timeout",
         description=(
-            "Max allowed duration the job may be active before Cloud Run will "
-            "actively try to mark it failed and kill associated containers (maximum of 86400 seconds, 1 day)."
+            "Max allowed time duration the Job may be active before Cloud Run will "
+            " actively try to mark it failed and kill associated containers (maximum of 86400 seconds, 1 day)."
         ),
     )
     vpc_connector_name: Optional[str] = Field(
@@ -397,7 +416,7 @@ class CloudRunWorkerV2Variables(BaseVariables):
             "of Cloud Run Job. By default Cloud Run jobs run as the default "
             "Compute Engine Service Account."
         ),
-        example="service-account@example.iam.gserviceaccount.com",
+        examples=["service-account@example.iam.gserviceaccount.com"],
     )
 
 
@@ -467,35 +486,6 @@ class CloudRunWorkerV2(BaseWorker):
 
             return result
 
-    async def kill_infrastructure(
-        self,
-        infrastructure_pid: str,
-        configuration: CloudRunWorkerJobV2Configuration,
-        grace_seconds: int = 30,
-    ):
-        """
-        Stops the Cloud Run job.
-
-        Args:
-            infrastructure_pid: The ID of the infrastructure to stop.
-            configuration: The configuration for the job.
-            grace_seconds: The number of seconds to wait before stopping the job.
-        """
-        if grace_seconds != 30:
-            self._logger.warning(
-                f"Kill grace period of {grace_seconds}s requested, but GCP does not "
-                "support dynamic grace period configuration. See here for more info: "
-                "https://cloud.google.com/run/docs/reference/rest/v1/namespaces.jobs/delete"  # noqa
-            )
-
-        with self._get_client(configuration=configuration) as cr_client:
-            await run_sync_in_worker_thread(
-                self._stop_job,
-                cr_client=cr_client,
-                configuration=configuration,
-                job_name=infrastructure_pid,
-            )
-
     @staticmethod
     def _get_client(
         configuration: CloudRunWorkerJobV2Configuration,
@@ -788,7 +778,6 @@ class CloudRunWorkerV2(BaseWorker):
         Returns:
             The execution.
         """
-
         while execution.is_running():
             execution = ExecutionV2.get(
                 cr_client=cr_client,
@@ -828,32 +817,3 @@ class CloudRunWorkerV2(BaseWorker):
                 ) from exc
             else:
                 raise exc
-
-    @staticmethod
-    def _stop_job(
-        cr_client: Resource,
-        configuration: CloudRunWorkerJobV2Configuration,
-        job_name: str,
-    ):
-        """
-        Stops/deletes the Cloud Run job.
-
-        Args:
-            cr_client: The Cloud Run client.
-            configuration: The configuration for the job.
-            job_name: The name of the job to stop.
-        """
-        try:
-            JobV2.delete(
-                cr_client=cr_client,
-                project=configuration.project,
-                location=configuration.region,
-                job_name=job_name,
-            )
-        except Exception as exc:
-            if "does not exist" in str(exc):
-                raise InfrastructureNotFound(
-                    f"Cannot stop Cloud Run Job; the job name {job_name!r} "
-                    "could not be found."
-                ) from exc
-            raise
