@@ -1,4 +1,4 @@
-""" <!-- # noqa -->
+"""<!-- # noqa -->
 
 Module containing the custom worker used for executing flow runs as Vertex AI Custom Jobs.
 
@@ -16,8 +16,9 @@ prefect worker start --pool 'my-vertex-pool'
 
 ## Configuration
 Read more about configuring work pools
-[here](https://docs.prefect.io/latest/concepts/work-pools/#work-pool-overview).
+[here](https://docs.prefect.io/3.0/deploy/infrastructure-concepts/work-pools).
 """
+
 import asyncio
 import datetime
 import re
@@ -27,9 +28,9 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple
 from uuid import uuid4
 
 import anyio
-from pydantic import VERSION as PYDANTIC_VERSION
+from pydantic import Field, field_validator
+from slugify import slugify
 
-from prefect.exceptions import InfrastructureNotFound
 from prefect.logging.loggers import PrefectLogAdapter
 from prefect.utilities.pydantic import JsonPatch
 from prefect.workers.base import (
@@ -38,14 +39,6 @@ from prefect.workers.base import (
     BaseWorker,
     BaseWorkerResult,
 )
-
-if PYDANTIC_VERSION.startswith("2."):
-    from pydantic.v1 import Field, validator
-else:
-    from pydantic import Field, validator
-
-from slugify import slugify
-
 from prefect_gcp.credentials import GcpCredentials
 
 # to prevent "Failed to load collection" from surfacing
@@ -60,7 +53,6 @@ try:
         Scheduling,
         WorkerPoolSpec,
     )
-    from google.cloud.aiplatform_v1.types.job_service import CancelCustomJobRequest
     from google.cloud.aiplatform_v1.types.job_state import JobState
     from google.cloud.aiplatform_v1.types.machine_resources import DiskSpec, MachineSpec
     from google.protobuf.duration_pb2 import Duration
@@ -86,7 +78,7 @@ class VertexAIWorkerVariables(BaseVariables):
 
     region: str = Field(
         description="The region where the Vertex AI Job resides.",
-        example="us-central1",
+        examples=["us-central1"],
     )
     image: str = Field(
         title="Image Name",
@@ -96,7 +88,7 @@ class VertexAIWorkerVariables(BaseVariables):
             "to the project and region where the container image is stored. See "
             "https://cloud.google.com/vertex-ai/docs/training/create-custom-container"
         ),
-        example="gcr.io/your-project/your-repo:latest",
+        examples=["gcr.io/your-project/your-repo:latest"],
     )
     credentials: Optional[GcpCredentials] = Field(
         title="GCP Credentials",
@@ -120,7 +112,7 @@ class VertexAIWorkerVariables(BaseVariables):
             "The type of accelerator to attach to the machine. "
             "See https://cloud.google.com/vertex-ai/docs/reference/rest/v1/MachineSpec"
         ),
-        example="NVIDIA_TESLA_K80",
+        examples=["NVIDIA_TESLA_K80"],
         default=None,
     )
     accelerator_count: Optional[int] = Field(
@@ -129,7 +121,7 @@ class VertexAIWorkerVariables(BaseVariables):
             "The number of accelerators to attach to the machine. "
             "See https://cloud.google.com/vertex-ai/docs/reference/rest/v1/MachineSpec"
         ),
-        example=1,
+        examples=[1],
         default=None,
     )
     boot_disk_type: str = Field(
@@ -226,7 +218,7 @@ class VertexAIWorkerJobConfiguration(BaseJobConfiguration):
 
     region: str = Field(
         description="The region where the Vertex AI Job resides.",
-        example="us-central1",
+        examples=["us-central1"],
     )
     credentials: Optional[GcpCredentials] = Field(
         title="GCP Credentials",
@@ -237,31 +229,33 @@ class VertexAIWorkerJobConfiguration(BaseJobConfiguration):
     )
 
     job_spec: Dict[str, Any] = Field(
-        template={
-            "service_account_name": "{{ service_account_name }}",
-            "network": "{{ network }}",
-            "reserved_ip_ranges": "{{ reserved_ip_ranges }}",
-            "maximum_run_time_hours": "{{ maximum_run_time_hours }}",
-            "worker_pool_specs": [
-                {
-                    "replica_count": 1,
-                    "container_spec": {
-                        "image_uri": "{{ image }}",
-                        "command": "{{ command }}",
-                        "args": [],
-                    },
-                    "machine_spec": {
-                        "machine_type": "{{ machine_type }}",
-                        "accelerator_type": "{{ accelerator_type }}",
-                        "accelerator_count": "{{ accelerator_count }}",
-                    },
-                    "disk_spec": {
-                        "boot_disk_type": "{{ boot_disk_type }}",
-                        "boot_disk_size_gb": "{{ boot_disk_size_gb }}",
-                    },
-                }
-            ],
-        }
+        json_schema_extra=dict(
+            template={
+                "service_account_name": "{{ service_account_name }}",
+                "network": "{{ network }}",
+                "reserved_ip_ranges": "{{ reserved_ip_ranges }}",
+                "maximum_run_time_hours": "{{ maximum_run_time_hours }}",
+                "worker_pool_specs": [
+                    {
+                        "replica_count": 1,
+                        "container_spec": {
+                            "image_uri": "{{ image }}",
+                            "command": "{{ command }}",
+                            "args": [],
+                        },
+                        "machine_spec": {
+                            "machine_type": "{{ machine_type }}",
+                            "accelerator_type": "{{ accelerator_type }}",
+                            "accelerator_count": "{{ accelerator_count }}",
+                        },
+                        "disk_spec": {
+                            "boot_disk_type": "{{ boot_disk_type }}",
+                            "boot_disk_size_gb": "{{ boot_disk_size_gb }}",
+                        },
+                    }
+                ],
+            }
+        ),
     )
     job_watch_poll_interval: float = Field(
         default=5.0,
@@ -347,7 +341,8 @@ class VertexAIWorkerJobConfiguration(BaseJobConfiguration):
 
         self.job_spec["service_account_name"] = service_account_to_use
 
-    @validator("job_spec")
+    @field_validator("job_spec")
+    @classmethod
     def _ensure_job_spec_includes_required_attributes(cls, value: Dict[str, Any]):
         """
         Ensures that the job spec includes all required components.
@@ -545,7 +540,7 @@ class VertexAIWorker(BaseWorker):
         until_states: Tuple["JobState"],
         configuration: VertexAIWorkerJobConfiguration,
         logger: PrefectLogAdapter,
-        timeout: int = None,
+        timeout: Optional[int] = None,
     ) -> "CustomJob":
         """
         Polls job run to see if status changed.
@@ -615,50 +610,3 @@ class VertexAIWorker(BaseWorker):
                 regex_pattern=_DISALLOWED_GCP_LABEL_CHARACTERS,
             )
         return compatible_labels
-
-    async def kill_infrastructure(
-        self,
-        infrastructure_pid: str,
-        configuration: VertexAIWorkerJobConfiguration,
-        grace_seconds: int = 30,
-    ):
-        """
-        Stops a job running in Vertex AI upon flow cancellation,
-        based on the provided infrastructure PID + run configuration.
-        """
-        if grace_seconds != 30:
-            self._logger.warning(
-                f"Kill grace period of {grace_seconds}s requested, but GCP does not "
-                "support dynamic grace period configuration. See here for more info: "
-                "https://cloud.google.com/vertex-ai/docs/reference/rest/v1/projects.locations.customJobs/cancel"  # noqa
-            )
-
-        client_options = ClientOptions(
-            api_endpoint=f"{configuration.region}-aiplatform.googleapis.com"
-        )
-        job_service_async_client = (
-            configuration.credentials.get_job_service_async_client(
-                client_options=client_options
-            )
-        )
-        await self._stop_job(
-            client=job_service_async_client,
-            vertex_job_name=infrastructure_pid,
-        )
-
-    async def _stop_job(self, client: "JobServiceAsyncClient", vertex_job_name: str):
-        """
-        Calls the `cancel_custom_job` method on the Vertex AI Job Service Client.
-        """
-        cancel_custom_job_request = CancelCustomJobRequest(name=vertex_job_name)
-        try:
-            await client.cancel_custom_job(
-                request=cancel_custom_job_request,
-            )
-        except Exception as exc:
-            if "does not exist" in str(exc):
-                raise InfrastructureNotFound(
-                    f"Cannot stop Vertex AI job; the job name {vertex_job_name!r} "
-                    "could not be found."
-                ) from exc
-            raise
