@@ -1,16 +1,8 @@
 import uuid
 from unittest.mock import Mock
 
-import anyio
-from pydantic import VERSION as PYDANTIC_VERSION
-
-if PYDANTIC_VERSION.startswith("2."):
-    import pydantic.v1 as pydantic
-else:
-    import pydantic
-
+import pydantic
 import pytest
-from googleapiclient.errors import HttpError
 from prefect_gcp.credentials import GcpCredentials
 from prefect_gcp.utilities import slugify_name
 from prefect_gcp.workers.cloud_run import (
@@ -19,9 +11,9 @@ from prefect_gcp.workers.cloud_run import (
     CloudRunWorkerResult,
 )
 
-from prefect.client.schemas import FlowRun
-from prefect.exceptions import InfrastructureNotFound
+from prefect.client.schemas.objects import FlowRun
 from prefect.server.schemas.actions import DeploymentCreate
+from prefect.utilities.dockerutils import get_prefect_image_name
 from prefect.utilities.schema_tools.validation import (
     ValidationError as PrefectValidationError,
 )
@@ -64,7 +56,6 @@ def flow_run():
 def cloud_run_worker_job_config(service_account_info, jobs_body):
     return CloudRunWorkerJobConfiguration(
         name="my-job-name",
-        image="gcr.io//not-a/real-image",
         region="middle-earth2",
         job_body=jobs_body,
         credentials=GcpCredentials(service_account_info=service_account_info),
@@ -75,7 +66,6 @@ def cloud_run_worker_job_config(service_account_info, jobs_body):
 def cloud_run_worker_job_config_noncompliant_name(service_account_info, jobs_body):
     return CloudRunWorkerJobConfiguration(
         name="MY_JOB_NAME",
-        image="gcr.io//not-a/real-image",
         region="middle-earth2",
         job_body=jobs_body,
         credentials=GcpCredentials(service_account_info=service_account_info),
@@ -113,17 +103,14 @@ class TestCloudRunWorkerJobConfiguration:
         assert container["env"][0]["value"] == "b"
 
     def test_populate_image_if_not_present(self, cloud_run_worker_job_config):
-        container = cloud_run_worker_job_config.job_body["spec"]["template"]["spec"][
-            "template"
-        ]["spec"]["containers"][0]
-
-        assert "image" not in container
-
         cloud_run_worker_job_config._populate_image_if_not_present()
 
-        # defaults to prefect image
-        assert "image" in container
-        assert container["image"].startswith("docker.io/prefecthq/prefect:")
+        assert (
+            cloud_run_worker_job_config.job_body["spec"]["template"]["spec"][
+                "template"
+            ]["spec"]["containers"][0]["image"]
+            == f"docker.io/{get_prefect_image_name()}"
+        )
 
     def test_populate_image_doesnt_overwrite(self, cloud_run_worker_job_config):
         image = "my-first-image"
@@ -229,16 +216,13 @@ class TestCloudRunWorkerJobConfiguration:
         with pytest.raises(pydantic.ValidationError) as excinfo:
             await CloudRunWorkerJobConfiguration.from_template_and_values(template, {})
 
-        assert excinfo.value.errors() == [
-            {
-                "loc": ("job_body",),
-                "msg": (
-                    "Job is missing required attributes at the following paths: "
-                    "/apiVersion, /kind, /metadata, /spec"
-                ),
-                "type": "value_error",
-            }
-        ]
+        assert len(err := excinfo.value.errors()) == 1
+        assert err[0]["loc"] == ("job_body",)
+        assert "Value error, Job is missing required attributes" in err[0]["msg"]
+        assert all(
+            key in err[0]["msg"]
+            for key in ["/apiVersion", "/kind", "/metadata", "/spec"]
+        )
 
     async def test_validates_for_a_job_body_missing_deeper_attributes(self):
         template = CloudRunWorker.get_default_base_job_template()
@@ -253,17 +237,11 @@ class TestCloudRunWorkerJobConfiguration:
         with pytest.raises(pydantic.ValidationError) as excinfo:
             await CloudRunWorkerJobConfiguration.from_template_and_values(template, {})
 
-        assert excinfo.value.errors() == [
-            {
-                "loc": ("job_body",),
-                "msg": (
-                    "Job is missing required attributes at the following paths: "
-                    "/metadata/annotations, "
-                    "/spec/template/spec/template/spec/containers"
-                ),
-                "type": "value_error",
-            }
-        ]
+        assert len(err := excinfo.value.errors()) == 1
+        assert err[0]["loc"] == ("job_body",)
+        assert "Job is missing required attributes" in err[0]["msg"]
+        assert "/metadata/annotations" in err[0]["msg"]
+        assert "/spec/template/spec/template/spec/containers" in err[0]["msg"]
 
     async def test_validates_for_a_job_with_incompatible_values(self):
         """We should give a human-friendly error when the user provides a custom Job
@@ -292,19 +270,14 @@ class TestCloudRunWorkerJobConfiguration:
         with pytest.raises(pydantic.ValidationError) as excinfo:
             await CloudRunWorkerJobConfiguration.from_template_and_values(template, {})
 
-        assert excinfo.value.errors() == [
-            {
-                "loc": ("job_body",),
-                "msg": (
-                    "Job has incompatible values for the following attributes: "
-                    "/apiVersion must have value 'run.googleapis.com/v1', "
-                    "/kind must have value 'Job', "
-                    "/metadata/annotations/run.googleapis.com~1launch-stage "
-                    "must have value 'BETA'"
-                ),
-                "type": "value_error",
-            }
-        ]
+        assert len(err := excinfo.value.errors()) == 1
+        assert err[0]["loc"] == ("job_body",)
+        assert "/apiVersion must have value 'run.googleapis.com/v1'" in err[0]["msg"]
+        assert "/kind must have value 'Job'" in err[0]["msg"]
+        assert (
+            "/metadata/annotations/run.googleapis.com~1launch-stage must have value 'BETA'"
+            in err[0]["msg"]
+        )
 
 
 class TestCloudRunWorkerValidConfiguration:
@@ -313,7 +286,7 @@ class TestCloudRunWorkerValidConfiguration:
         deployment = DeploymentCreate(
             name="my-deployment",
             flow_id=uuid.uuid4(),
-            infra_overrides={"region": "test-region1", "cpu": cpu},
+            job_variables={"region": "test-region1", "cpu": cpu},
         )
         with pytest.raises(PrefectValidationError) as exc:
             deployment.check_valid_configuration(
@@ -327,7 +300,7 @@ class TestCloudRunWorkerValidConfiguration:
         deployment = DeploymentCreate(
             name="my-deployment",
             flow_id=uuid.uuid4(),
-            infra_overrides={"region": "test-region1", "cpu": cpu},
+            job_variables={"region": "test-region1", "cpu": cpu},
         )
         deployment.check_valid_configuration(
             CloudRunWorker.get_default_base_job_template()
@@ -338,7 +311,7 @@ class TestCloudRunWorkerValidConfiguration:
         deployment = DeploymentCreate(
             name="my-deployment",
             flow_id=uuid.uuid4(),
-            infra_overrides={"region": "test-region1", "memory": memory},
+            job_variables={"region": "test-region1", "memory": memory},
         )
         with pytest.raises(PrefectValidationError) as exc:
             deployment.check_valid_configuration(
@@ -351,7 +324,7 @@ class TestCloudRunWorkerValidConfiguration:
         deployment = DeploymentCreate(
             name="my-deployment",
             flow_id=uuid.uuid4(),
-            infra_overrides={"region": "test-region1", "memory": memory},
+            job_variables={"region": "test-region1", "memory": memory},
         )
         deployment.check_valid_configuration(
             CloudRunWorker.get_default_base_job_template()
@@ -595,7 +568,7 @@ class TestCloudRunWorker:
             def raise_exception(*args, **kwargs):
                 raise Exception("This is an intentional exception")
 
-            monkeypatch.setattr("prefect_gcp.cloud_run.Job.get", raise_exception)
+            monkeypatch.setattr("prefect_gcp.utilities.Job.get", raise_exception)
 
             with pytest.raises(Exception):
                 await cloud_run_worker.run(flow_run, cloud_run_worker_job_config)
@@ -657,76 +630,10 @@ class TestCloudRunWorker:
             def raise_exception(*args, **kwargs):
                 raise Exception("This is an intentional exception")
 
-            monkeypatch.setattr("prefect_gcp.cloud_run.Execution.get", raise_exception)
+            monkeypatch.setattr("prefect_gcp.utilities.Execution.get", raise_exception)
 
             with pytest.raises(Exception):
                 await cloud_run_worker.run(flow_run, cloud_run_worker_job_config)
             calls = list_mock_calls(mock_client, 2)
             for call, expected_call in zip(calls, expected_calls):
                 assert call.startswith(expected_call)
-
-    async def test_kill(self, mock_client, cloud_run_worker_job_config, flow_run):
-        async with CloudRunWorker("my-work-pool") as cloud_run_worker:
-            cloud_run_worker_job_config.prepare_for_flow_run(flow_run, None, None)
-
-            mock_client.jobs().get().execute.return_value = self.job_ready
-            mock_client.jobs().run().execute.return_value = self.job_ready
-            mock_client.executions().get().execute.return_value = (
-                self.execution_not_found
-            )  # noqa
-
-            with anyio.fail_after(5):
-                async with anyio.create_task_group() as tg:
-                    identifier = await tg.start(
-                        cloud_run_worker.run, flow_run, cloud_run_worker_job_config
-                    )
-                    await cloud_run_worker.kill_infrastructure(
-                        identifier, cloud_run_worker_job_config
-                    )
-
-            actual_calls = list_mock_calls(mock_client=mock_client)
-            assert "call.jobs().delete().execute()" in actual_calls
-
-    def failed_to_get(self):
-        raise HttpError(Mock(reason="does not exist"), content=b"")
-
-    async def test_kill_not_found(
-        self, mock_client, cloud_run_worker_job_config, flow_run
-    ):
-        async with CloudRunWorker("my-work-pool") as cloud_run_worker:
-            cloud_run_worker_job_config.prepare_for_flow_run(flow_run, None, None)
-
-            mock_client.jobs().delete().execute.side_effect = self.failed_to_get
-            with pytest.raises(
-                InfrastructureNotFound, match="Cannot stop Cloud Run Job; the job name"
-            ):
-                await cloud_run_worker.kill_infrastructure(
-                    "non-existent", cloud_run_worker_job_config
-                )
-
-    async def test_kill_grace_seconds(
-        self, mock_client, cloud_run_worker_job_config, flow_run, caplog
-    ):
-        async with CloudRunWorker("my-work-pool") as cloud_run_worker:
-            cloud_run_worker_job_config.prepare_for_flow_run(flow_run, None, None)
-
-            mock_client.jobs().get().execute.return_value = self.job_ready
-            mock_client.jobs().run().execute.return_value = self.job_ready
-            mock_client.executions().get().execute.return_value = (
-                self.execution_not_found
-            )
-
-            with anyio.fail_after(5):
-                async with anyio.create_task_group() as tg:
-                    identifier = await tg.start(
-                        cloud_run_worker.run, flow_run, cloud_run_worker_job_config
-                    )
-                    await cloud_run_worker.kill_infrastructure(
-                        identifier, cloud_run_worker_job_config, grace_seconds=42
-                    )
-
-            for record in caplog.records:
-                if "Kill grace period of 42s requested, but GCP does not" in record.msg:
-                    break
-            else:
-                raise AssertionError("Expected message not found.")
