@@ -15,7 +15,6 @@ from prefect_gcp.cloud_storage import (
 )
 
 from prefect import flow
-from prefect.deployments import Deployment
 
 
 def test_cloud_storage_create_bucket(gcp_credentials):
@@ -564,16 +563,3 @@ class TestGcsBucket:
             gcs_bucket_with_bucket_folder.upload_from_dataframe(
                 df=pandas_dataframe, to_path=to_path, serialization_format="pickle"
             )
-
-    def test_basepath(self, gcs_bucket_with_bucket_folder, monkeypatch):
-        monkeypatch.setattr(
-            "prefect_gcp.GcpCredentials.get_cloud_storage_client", lambda x: x
-        )
-        assert gcs_bucket_with_bucket_folder.basepath == "base_folder/"
-
-        deployment = Deployment(
-            flow_name="test-flow-name",
-            name="test-deployment",
-            storage=gcs_bucket_with_bucket_folder,
-        )
-        assert deployment.location == ""
