@@ -1,17 +1,8 @@
 import uuid
-from types import SimpleNamespace
 from unittest.mock import MagicMock
 
-import anyio
-from pydantic import VERSION as PYDANTIC_VERSION
-
-if PYDANTIC_VERSION.startswith("2."):
-    import pydantic.v1 as pydantic
-else:
-    import pydantic
-
+import pydantic
 import pytest
-from google.cloud.aiplatform_v1.types.job_service import CancelCustomJobRequest
 from google.cloud.aiplatform_v1.types.job_state import JobState
 from prefect_gcp.workers.vertex import (
     VertexAIWorker,
@@ -20,7 +11,6 @@ from prefect_gcp.workers.vertex import (
 )
 
 from prefect.client.schemas import FlowRun
-from prefect.exceptions import InfrastructureNotFound
 
 
 @pytest.fixture
@@ -70,16 +60,12 @@ class TestVertexAIWorkerJobConfiguration:
                 base_job_template, {"credentials": gcp_credentials}
             )
 
-        assert excinfo.value.errors() == [
-            {
-                "loc": ("job_spec",),
-                "msg": (
-                    "Job is missing required attributes at the following paths: "
-                    "/maximum_run_time_hours, /worker_pool_specs"
-                ),
-                "type": "value_error",
-            }
-        ]
+        assert len(errs := excinfo.value.errors()) == 1
+        loc, msg, type_ = [errs[0].get(k) for k in ("loc", "msg", "type")]
+        assert "job_spec" in str(loc)
+        assert type_ == "value_error"
+        assert "/maximum_run_time_hours" in msg
+        assert "/worker_pool_specs" in msg
 
     async def test_validate_incomplete_worker_pool_spec(self, gcp_credentials):
         base_job_template = VertexAIWorker.get_default_base_job_template()
@@ -102,18 +88,13 @@ class TestVertexAIWorkerJobConfiguration:
                 base_job_template, {"credentials": gcp_credentials}
             )
 
-        assert excinfo.value.errors() == [
-            {
-                "loc": ("job_spec",),
-                "msg": (
-                    "Job is missing required attributes at the following paths: "
-                    "/worker_pool_specs/0/container_spec/image_uri, "
-                    "/worker_pool_specs/0/disk_spec, "
-                    "/worker_pool_specs/0/machine_spec/machine_type"
-                ),
-                "type": "value_error",
-            }
-        ]
+        assert len(errs := excinfo.value.errors()) == 1
+        loc, msg, type_ = [errs[0].get(k) for k in ("loc", "msg", "type")]
+        assert "job_spec" in str(loc)
+        assert type_ == "value_error"
+        assert "/worker_pool_specs/0/container_spec/image_uri" in msg
+        assert "/worker_pool_specs/0/disk_spec" in msg
+        assert "/worker_pool_specs/0/machine_spec/machine_type" in msg
 
     def test_gcp_project(self, job_config: VertexAIWorkerJobConfiguration):
         assert job_config.project == "gcp_credentials_project"
@@ -224,56 +205,3 @@ class TestVertexAIWorker:
             assert result == VertexAIWorkerResult(
                 status_code=1, identifier=job_display_name
             )
-
-    async def test_kill_infrastructure(self, flow_run, job_config):
-        mock = job_config.credentials.job_service_async_client.create_custom_job
-        # the CancelCustomJobRequest class seems to reject a MagicMock value
-        # so here, we'll use a SimpleNamespace as the mocked return values
-        mock.return_value = SimpleNamespace(
-            name="foobar", state=JobState.JOB_STATE_PENDING
-        )
-
-        async with VertexAIWorker("test-pool") as worker:
-            with anyio.fail_after(10):
-                async with anyio.create_task_group() as tg:
-                    result = await tg.start(worker.run, flow_run, job_config)
-                await worker.kill_infrastructure(result, job_config)
-
-            mock = job_config.credentials.job_service_async_client.cancel_custom_job
-            assert mock.call_count == 1
-            mock.assert_called_with(request=CancelCustomJobRequest(name="foobar"))
-
-    async def test_kill_infrastructure_no_grace_seconds(
-        self, flow_run, job_config, caplog
-    ):
-        mock = job_config.credentials.job_service_async_client.create_custom_job
-        mock.return_value = SimpleNamespace(
-            name="bazzbar", state=JobState.JOB_STATE_PENDING
-        )
-        async with VertexAIWorker("test-pool") as worker:
-            input_grace_period = 32
-
-            with anyio.fail_after(10):
-                async with anyio.create_task_group() as tg:
-                    identifier = await tg.start(worker.run, flow_run, job_config)
-                await worker.kill_infrastructure(
-                    identifier, job_config, input_grace_period
-                )
-            for record in caplog.records:
-                if (
-                    f"Kill grace period of {input_grace_period}s "
-                    "requested, but GCP does not"
-                ) in record.msg:
-                    break
-            else:
-                raise AssertionError("Expected message not found.")
-
-    async def test_kill_infrastructure_not_found(self, job_config):
-        async with VertexAIWorker("test-pool") as worker:
-            job_config.credentials.job_service_async_client.cancel_custom_job.side_effect = Exception(
-                "does not exist"
-            )
-            with pytest.raises(
-                InfrastructureNotFound, match="Cannot stop Vertex AI job"
-            ):
-                await worker.kill_infrastructure("foobarbazz", job_config)
